@@ -32,6 +32,7 @@ from .type_defs import (
     CreateEventActionResponseTypeDef,
     CreateJobResponseTypeDef,
     CreateRevisionResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     EventTypeDef,
     GetAssetResponseTypeDef,
     GetDataSetResponseTypeDef,
@@ -106,7 +107,7 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#can_paginate)
         """
 
-    def cancel_job(self, *, JobId: str) -> None:
+    def cancel_job(self, *, JobId: str) -> EmptyResponseMetadataTypeDef:
         """
         This operation cancels a job.
 
@@ -130,7 +131,7 @@ class DataExchangeClient(BaseClient):
         """
 
     def create_event_action(
-        self, *, Action: "ActionTypeDef", Event: "EventTypeDef"
+        self, *, Action: ActionTypeDef, Event: EventTypeDef
     ) -> CreateEventActionResponseTypeDef:
         """
         This operation creates an event action.
@@ -140,7 +141,7 @@ class DataExchangeClient(BaseClient):
         """
 
     def create_job(
-        self, *, Details: "RequestDetailsTypeDef", Type: TypeType
+        self, *, Details: RequestDetailsTypeDef, Type: TypeType
     ) -> CreateJobResponseTypeDef:
         """
         This operation creates a job.
@@ -159,7 +160,9 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#create_revision)
         """
 
-    def delete_asset(self, *, AssetId: str, DataSetId: str, RevisionId: str) -> None:
+    def delete_asset(
+        self, *, AssetId: str, DataSetId: str, RevisionId: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         This operation deletes an asset.
 
@@ -167,7 +170,7 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#delete_asset)
         """
 
-    def delete_data_set(self, *, DataSetId: str) -> None:
+    def delete_data_set(self, *, DataSetId: str) -> EmptyResponseMetadataTypeDef:
         """
         This operation deletes a data set.
 
@@ -175,7 +178,7 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#delete_data_set)
         """
 
-    def delete_event_action(self, *, EventActionId: str) -> None:
+    def delete_event_action(self, *, EventActionId: str) -> EmptyResponseMetadataTypeDef:
         """
         This operation deletes the event action.
 
@@ -183,7 +186,7 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#delete_event_action)
         """
 
-    def delete_revision(self, *, DataSetId: str, RevisionId: str) -> None:
+    def delete_revision(self, *, DataSetId: str, RevisionId: str) -> EmptyResponseMetadataTypeDef:
         """
         This operation deletes a revision.
 
@@ -349,7 +352,9 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#start_job)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Mapping[str, str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         This operation tags a resource.
 
@@ -357,7 +362,9 @@ class DataExchangeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         This operation removes one or more tags from a resource.
 
@@ -386,7 +393,7 @@ class DataExchangeClient(BaseClient):
         """
 
     def update_event_action(
-        self, *, EventActionId: str, Action: "ActionTypeDef" = ...
+        self, *, EventActionId: str, Action: ActionTypeDef = ...
     ) -> UpdateEventActionResponseTypeDef:
         """
         This operation updates the event action.
