@@ -67,7 +67,7 @@ class ListDataSetRevisionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, DataSetId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, DataSetId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDataSetRevisionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions.paginate)
@@ -82,7 +82,7 @@ class ListDataSetsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Origin: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Origin: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDataSetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets.paginate)
@@ -97,7 +97,7 @@ class ListEventActionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, EventSourceId: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, EventSourceId: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEventActionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#DataExchange.Paginator.ListEventActions.paginate)
@@ -116,7 +116,7 @@ class ListJobsPaginator(Boto3Paginator):
         *,
         DataSetId: str = ...,
         RevisionId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs.paginate)
@@ -131,7 +131,7 @@ class ListRevisionAssetsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, DataSetId: str, RevisionId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, DataSetId: str, RevisionId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRevisionAssetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets.paginate)
